[gimp] libgimp*: some API doc fixes



commit 24da0007a4ce89c72096ab03032f2df5e3b3b41d
Author: Michael Natterer <mitch gimp org>
Date:   Sun May 31 14:40:20 2015 +0200

    libgimp*: some API doc fixes

 libgimpbase/gimpmetadata.c       |    9 +++++----
 libgimpbase/gimpvaluearray.c     |   20 +++++++++++---------
 libgimpconfig/gimpconfig-iface.c |    4 ++--
 libgimpmath/gimpvector.c         |   10 +++++-----
 4 files changed, 23 insertions(+), 20 deletions(-)
---
diff --git a/libgimpbase/gimpvaluearray.c b/libgimpbase/gimpvaluearray.c
index e3e5250..cb39e1f 100644
--- a/libgimpbase/gimpvaluearray.c
+++ b/libgimpbase/gimpvaluearray.c
@@ -30,7 +30,7 @@
 
 
 /**
- * SECTION:value_arrays
+ * SECTION:gimpvaluearray
  * @short_description: A container structure to maintain an array of
  *     generic values
  * @see_also: #GValue, #GParamSpecValueArray, gimp_param_spec_value_array()
@@ -72,11 +72,11 @@ G_DEFINE_BOXED_TYPE (GimpValueArray, gimp_value_array,
 /**
  * gimp_value_array_index:
  * @value_array: #GimpValueArray to get a value from
- * @index_: index of the value of interest
+ * @index: index of the value of interest
  *
- * Return a pointer to the value at @index_ containd in @value_array.
+ * Return a pointer to the value at @index containd in @value_array.
  *
- * Returns: (transfer none): pointer to a value at @index_ in @value_array
+ * Returns: (transfer none): pointer to a value at @index in @value_array
  *
  * Since: GIMP 2.10
  */
@@ -156,6 +156,8 @@ gimp_value_array_new (gint n_prealloced)
  *
  * Adds a reference to a #GimpValueArray.
  *
+ * Return value: the same @value_array
+ *
  * Since: GIMP 2.10
  */
 GimpValueArray *
@@ -253,7 +255,7 @@ gimp_value_array_append (GimpValueArray *value_array,
 /**
  * gimp_value_array_insert:
  * @value_array: #GimpValueArray to add an element to
- * @index_: insertion position, must be &lt;= value_array-&gt;n_values
+ * @index: insertion position, must be &lt;= value_array-&gt;n_values
  * @value: (allow-none): #GValue to copy into #GimpValueArray, or %NULL
  *
  * Insert a copy of @value at specified position into @value_array. If @value
@@ -294,11 +296,11 @@ gimp_value_array_insert (GimpValueArray *value_array,
 /**
  * gimp_value_array_remove:
  * @value_array: #GimpValueArray to remove an element from
- * @index_: position of value to remove, which must be less than
- *          <code>value_array-><link
- *          linkend="GimpValueArray.n-values">n_values</link></code>
+ * @index: position of value to remove, which must be less than
+ *         <code>value_array-><link
+ *         linkend="GimpValueArray.n-values">n_values</link></code>
  *
- * Remove the value at position @index_ from @value_array.
+ * Remove the value at position @index from @value_array.
  *
  * Returns: (transfer none): the #GimpValueArray passed in as @value_array
  *
diff --git a/libgimpconfig/gimpconfig-iface.c b/libgimpconfig/gimpconfig-iface.c
index 9710de9..d189c44 100644
--- a/libgimpconfig/gimpconfig-iface.c
+++ b/libgimpconfig/gimpconfig-iface.c
@@ -341,14 +341,14 @@ gimp_config_serialize_to_gfile (GimpConfig   *config,
 /**
  * gimp_config_serialize_to_stream:
  * @config: a #GObject that implements the #GimpConfigInterface.
- * @stream: the #GOutputStream to write the configuration to.
+ * @output: the #GOutputStream to write the configuration to.
  * @header: optional file header (must be ASCII only)
  * @footer: optional file footer (must be ASCII only)
  * @data: user data passed to the serialize implementation.
  * @error: return location for a possible error
  *
  * Serializes the object properties of @config to the stream specified
- * by @stream.
+ * by @output.
  *
  * Return value: %TRUE if serialization succeeded, %FALSE otherwise.
  *
diff --git a/libgimpmath/gimpvector.c b/libgimpmath/gimpvector.c
index 95b1aea..3174060 100644
--- a/libgimpmath/gimpvector.c
+++ b/libgimpmath/gimpvector.c
@@ -468,11 +468,11 @@ gimp_vector2_rotate_val (GimpVector2 vector,
  * Compute a normalized perpendicular vector to @vector
  *
  * Returns: a #GimpVector2 perpendicular to @vector, with a length of 1.0.
- * 
- * Since: 2.8
+ *
+ * Since: GIMP 2.8
  **/
 GimpVector2
-gimp_vector2_normal (GimpVector2  *vector)
+gimp_vector2_normal (GimpVector2 *vector)
 {
   GimpVector2 result;
 
@@ -493,10 +493,10 @@ gimp_vector2_normal (GimpVector2  *vector)
  *
  * Returns: a #GimpVector2 perpendicular to @vector, with a length of 1.0.
  *
- * Since: 2.8
+ * Since: GIMP 2.8
  **/
 GimpVector2
-gimp_vector2_normal_val (GimpVector2  vector)
+gimp_vector2_normal_val (GimpVector2 vector)
 {
   GimpVector2 result;
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgimpbase/gimpmetadata.c b/libgimpbase/gimpmetadata.c
index 73ff2fc..3692423 100644
--- a/libgimpbase/gimpmetadata.c
+++ b/libgimpbase/gimpmetadata.c
@@ -746,8 +746,8 @@ gimp_metadata_set_pixel_size (GimpMetadata *metadata,
 
 /**
  * gimp_metadata_set_bits_per_sample:
  * @metadata: A #GimpMetadata instance.
  * @bps:      Bytes per pixel, per component
  *
  * Sets Exif.Image.BitsPerSample on @metadata.
  *
@@ -755,13 +755,14 @@ gimp_metadata_set_pixel_size (GimpMetadata *metadata,
  */
 void
 gimp_metadata_set_bits_per_sample (GimpMetadata *metadata,
-                                   gint          bps)
+                                   gint          bits_per_sample)
 {
   gchar buffer[32];
 
   g_return_if_fail (GEXIV2_IS_METADATA (metadata));
 
-  g_snprintf (buffer, sizeof (buffer), "%d %d %d", bps, bps, bps);
+  g_snprintf (buffer, sizeof (buffer), "%d %d %d",
+              bits_per_sample, bits_per_sample, bits_per_sample);
   gexiv2_metadata_set_tag_string (metadata, "Exif.Image.BitsPerSample", buffer);
 }
 
@@ -746,8 +746,8 @@ gimp_metadata_set_pixel_size (GimpMetadata *metadata,
 /**
  * gimp_metadata_set_bits_per_sample:
- * @metadata: A #GimpMetadata instance.
- * @bps:      Bytes per pixel, per component
+ * @metadata:        A #GimpMetadata instance.
+ * @bits_per_sample: Bits per pixel, per component
  *
  * Sets Exif.Image.BitsPerSample on @metadata.